==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/InMageRcmDiskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDiskInputArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.DiskAccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * InMageRcm disk input.
 * @property diskEncryptionSetId The DiskEncryptionSet ARM Id.
 * @property diskId The disk Id.
 * @property diskType The disk type.
 * @property logStorageAccountId The log storage account ARM Id.
 */
public data class InMageRcmDiskInputArgs(
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskId: Output<String>,
    public val diskType: Output<Either<String, DiskAccountType>>,
    public val logStorageAccountId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDiskInputArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDiskInputArgs =
        com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDiskInputArgs.builder()
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskId(diskId.applyValue({ args0 -> args0 }))
            .diskType(
                diskType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .logStorageAccountId(logStorageAccountId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InMageRcmDiskInputArgs].
 */
@PulumiTagMarker
public class InMageRcmDiskInputArgsBuilder internal constructor() {
    private var diskEncryptionSetId: Output<String>? = null

    private var diskId: Output<String>? = null

    private var diskType: Output<Either<String, DiskAccountType>>? = null

    private var logStorageAccountId: Output<String>? = null

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("uslligndogbqdbth")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The disk Id.
     */
    @JvmName("xyeydjohmfrluiya")
    public suspend fun diskId(`value`: Output<String>) {
        this.diskId = value
    }

    /**
     * @param value The disk type.
     */
    @JvmName("lhmdmfoymnobpkji")
    public suspend fun diskType(`value`: Output<Either<String, DiskAccountType>>) {
        this.diskType = value
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("snkojawpyflvvxgq")
    public suspend fun logStorageAccountId(`value`: Output<String>) {
        this.logStorageAccountId = value
    }

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("aaagaodnwwamuggl")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The disk Id.
     */
    @JvmName("xjefyakytrnsuomu")
    public suspend fun diskId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskId = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("mixytwallbnbxfuu")
    public suspend fun diskType(`value`: Either<String, DiskAccountType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("brfaexlctjwgdnag")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("esyddvqcdxfbujob")
    public fun diskType(`value`: DiskAccountType) {
        val toBeMapped = Either.ofRight<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("ghaogbaybehlidgm")
    public suspend fun logStorageAccountId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logStorageAccountId = mapped
    }

    internal fun build(): InMageRcmDiskInputArgs = InMageRcmDiskInputArgs(
        diskEncryptionSetId = diskEncryptionSetId,
        diskId = diskId ?: throw PulumiNullFieldException("diskId"),
        diskType = diskType ?: throw PulumiNullFieldException("diskType"),
        logStorageAccountId = logStorageAccountId ?: throw PulumiNullFieldException("logStorageAccountId"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/InMageRcmDiskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDiskInputArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.DiskAccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * InMageRcm disk input.
 * @property diskEncryptionSetId The DiskEncryptionSet ARM Id.
 * @property diskId The disk Id.
 * @property diskType The disk type.
 * @property logStorageAccountId The log storage account ARM Id.
 */
public data class InMageRcmDiskInputArgs(
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskId: Output<String>,
    public val diskType: Output<Either<String, DiskAccountType>>,
    public val logStorageAccountId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDiskInputArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDiskInputArgs =
        com.pulumi.azurenative.recoveryservices.inputs.InMageRcmDiskInputArgs.builder()
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskId(diskId.applyValue({ args0 -> args0 }))
            .diskType(
                diskType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .logStorageAccountId(logStorageAccountId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InMageRcmDiskInputArgs].
 */
@PulumiTagMarker
public class InMageRcmDiskInputArgsBuilder internal constructor() {
    private var diskEncryptionSetId: Output<String>? = null

    private var diskId: Output<String>? = null

    private var diskType: Output<Either<String, DiskAccountType>>? = null

    private var logStorageAccountId: Output<String>? = null

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("fflswqulsuqdotnw")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The disk Id.
     */
    @JvmName("rdogyjkkfdknicdt")
    public suspend fun diskId(`value`: Output<String>) {
        this.diskId = value
    }

    /**
     * @param value The disk type.
     */
    @JvmName("vccyyktqnroypfyw")
    public suspend fun diskType(`value`: Output<Either<String, DiskAccountType>>) {
        this.diskType = value
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("oggbmmknrcjesyyb")
    public suspend fun logStorageAccountId(`value`: Output<String>) {
        this.logStorageAccountId = value
    }

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("qcnvflbmdsdwrfrb")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The disk Id.
     */
    @JvmName("axdmksujiinbffqi")
    public suspend fun diskId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskId = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("bhjggfljhmqnlrfa")
    public suspend fun diskType(`value`: Either<String, DiskAccountType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("ljbxopoipyyuehhn")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("avftvadytejoruyh")
    public fun diskType(`value`: DiskAccountType) {
        val toBeMapped = Either.ofRight<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("oukidvqcuodwusdi")
    public suspend fun logStorageAccountId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logStorageAccountId = mapped
    }

    internal fun build(): InMageRcmDiskInputArgs = InMageRcmDiskInputArgs(
        diskEncryptionSetId = diskEncryptionSetId,
        diskId = diskId ?: throw PulumiNullFieldException("diskId"),
        diskType = diskType ?: throw PulumiNullFieldException("diskType"),
        logStorageAccountId = logStorageAccountId ?: throw PulumiNullFieldException("logStorageAccountId"),
    )
}
